package com.gic.haoban.manage.service.service.out.impl;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import cn.hutool.core.collection.CollectionUtil;

import com.gic.api.base.commons.Page;
import com.gic.commons.util.EntityUtil;
import com.gic.haoban.base.api.common.BasePageInfo;
import com.gic.haoban.common.utils.HaobanResponse;
import com.gic.haoban.common.utils.PageUtil;
import com.gic.haoban.manage.api.dto.DepartmentDTO;
import com.gic.haoban.manage.api.dto.StaffDTO;
import com.gic.haoban.manage.api.dto.StaffDepartmentRelatedDTO;
import com.gic.haoban.manage.api.service.StaffApiService;
import com.gic.haoban.manage.service.dao.mapper.StaffMapper;
import com.gic.haoban.manage.service.entity.TabHaobanStaff;
import com.gic.haoban.manage.service.entity.TabHaobanStaffDepartmentRelated;
import com.gic.haoban.manage.service.service.StaffDepartmentRelatedService;
import com.gic.haoban.manage.service.service.StaffService;
import com.github.pagehelper.PageHelper;

@Service
public class StaffApiServiceImpl implements StaffApiService {
	
	@Autowired
	StaffService staffService;
	@Autowired
	StaffMapper staffMapper;
	@Autowired
	StaffDepartmentRelatedService staffDepartmentRelatedService;

	@Override
	public StaffDTO selectById(String staffId) {
		TabHaobanStaff staff = staffService.selectById(staffId);
		return EntityUtil.changeEntityByJSON(StaffDTO.class, staff);
	}

	@Override
	public StaffDTO selectByNationcodeAndPhoneNumber(String wxEnterpriseId,String nationcode, String phoneNumber) {
		TabHaobanStaff staff = staffService.selectByNationcodeAndPhoneNumber(wxEnterpriseId,nationcode,phoneNumber);
		return EntityUtil.changeEntityByJSON(StaffDTO.class, staff);
	}

	@Override
	public HaobanResponse add(StaffDTO staff, String departmentIds) {
		HaobanResponse hr  = new HaobanResponse();
		hr.setErrorCode(1);
		Integer activeFlag = staff.getActiveFlag();
		TabHaobanStaff tab = EntityUtil.changeEntityByJSON(TabHaobanStaff.class, staff);
		String staffId = staffService.add(tab);
		//调接口获取
		String wxUserId = "";
		if(StringUtils.isNotBlank(wxUserId)){
			String[] departmentIdArr = departmentIds.split(",");
			for (String string : departmentIdArr) {
				StaffDepartmentRelatedDTO related = new StaffDepartmentRelatedDTO();
				related.setDepartmentId(string);
				related.setNationCode(staff.getNationCode());
				related.setPhoneNumber(staff.getPhoneNumber());
				related.setStaffId(staffId);
				related.setWxUserId(wxUserId);
				staffDepartmentRelatedService.add(related);
			}
		}else {
			hr.setErrorCode(0);
			hr.setMessage("微信端新增失败");
		}
		
		
		
		return hr;
	}

	@Override
	public List<StaffDepartmentRelatedDTO> listStaffDepartmentByStaffId(String staffId) {
		List<TabHaobanStaffDepartmentRelated> list = staffDepartmentRelatedService.listStaffDepartmentByStaffId(staffId);
		return EntityUtil.changeEntityListByJSON(StaffDepartmentRelatedDTO.class, list);
	}

	@Override
	public Page<StaffDTO> pageStaff(String departmentId, Integer activeFlag, String keyword, BasePageInfo pageInfo) {
		
		PageHelper.startPage(pageInfo.getPageNum(), pageInfo.getPageSize());
		List<TabHaobanStaffDepartmentRelated> list = staffDepartmentRelatedService.listByDepartmentId(departmentId);
		Set<String> staffIds = new HashSet<String>();
		for (TabHaobanStaffDepartmentRelated tabHaobanStaffDepartmentRelated : list) {
			staffIds.add(tabHaobanStaffDepartmentRelated.getStaffId());
		}
		return  PageUtil.changePageHelperToCurrentPage(staffService.pageStaff(staffIds, activeFlag, keyword),StaffDTO.class);
	}

	@Override
	public List<StaffDTO> listByIds(List<String> staffIds) {
		List<TabHaobanStaff> staffs = staffMapper.listByIds(staffIds);
		if(CollectionUtil.isNotEmpty(staffs)){
			List<StaffDTO> resultList = EntityUtil.changeEntityListByJSON(StaffDTO.class, staffs);
			return resultList;
		}else{
			return new ArrayList<StaffDTO>();
		}

	}

	@Override
	public void del(String staffDepartmentStaffRelatedId) {
		StaffDepartmentRelatedDTO related = staffDepartmentRelatedService.selectById(staffDepartmentStaffRelatedId);
		if(related != null) {
			List<TabHaobanStaffDepartmentRelated> relatedList = staffDepartmentRelatedService.listStaffDepartmentByStaffId(related.getStaffId());
			//只在当前门店
			if(relatedList.size() <= 1) {
				//微信接口删除
				staffDepartmentRelatedService.del(related);
			//走修改流程
			}else {
				
			}
		}
		
	}

	@Override
	public void wxGetAdd(String userId,String wxEnterpriseId) {
		//获取微信用户信息
		
		TabHaobanStaff staff = staffService.selectByUserId(userId);
		if(staff == null) {
			TabHaobanStaff tab = new TabHaobanStaff();
			staffService.add(tab);
			
			StaffDepartmentRelatedDTO dto = new StaffDepartmentRelatedDTO();
			staffDepartmentRelatedService.add(dto);
		}
		
		
	}

	@Override
	public void staffEdit(StaffDTO staffDTO, String departmentIds) {
		// TODO Auto-generated method stub
		
	}

}
